@@ -34,17 +34,30 @@ def main():
         vlan_id=dict(required=False),
         network_mtu=dict(required=False),
         nics=dict(required=False, type='list'),
-        node_network_info=dict(required=False, type='dict')
+        node_network_data=dict(required=False, type='dict')
     )
 
     module = AnsibleModule(argument_spec)
 
-    network_metadata = module.params['node_network_info']
+    network_metadata = module.params['node_network_data']
     if not network_metadata:
         links = []
         networks = []
 
         if module.params['ipv4_interface_mac']:
+            nic_id = module.params['ipv4_interface_mac']
+
+            if module.params['vlan_id']:
+                nic_id = 'vlan-%s' % module.params['ipv4_interface_mac']
+
+                links.append({
+                    'id': nic_id,
+                    'type': 'vlan',
+                    'vlan_id': module.params['vlan_id'],
+                    'vlan_link': module.params['ipv4_interface_mac'],
+                    'vlan_mac_address': module.params['ipv4_interface_mac'],
+                })
+
             links.append({
                 'id': module.params['ipv4_interface_mac'],
                 'type': 'phy',
@@ -55,8 +68,8 @@ def main():
             for nic in module.params['nics']:
                 if nic['mac'] == module.params['ipv4_interface_mac']:
                     networks.append({
-                        'id': 'ipv4-%s' % nic['mac'],
-                        'link': nic['mac'],
+                        'id': 'ipv4-%s' % nic_id,
+                        'link': nic_id,
                         'type': 'ipv4',
                         'ip_address': module.params['ipv4_address'],
                         'netmask': module.params['ipv4_subnet_mask'],
@@ -125,9 +138,9 @@ def main():
             'networks': networks,
             'services': services
         }
-        facts = {'network_metadata': network_metadata}
+    facts = {'network_metadata': network_metadata}
 
-        module.exit_json(changed=False, ansible_facts=facts)
+    module.exit_json(changed=False, ansible_facts=facts)
 
 
 # this is magic, see lib/ansible/module_common.py
